import stan
import arviz as az
import matplotlib.pyplot as plt
import seaborn as sb
import pandas as pd

N = 10
k = 7
with open('stan_binomial.stan') as f:
    sm = stan.build(f.read(), data = {'N':N, 'k':k})
fit = sm.sample(num_samples=10000)

i_data = az.from_pystan(posterior = fit, posterior_model = sm)
smry = az.summary(i_data)
print('Summary =\n',smry)

d_fm = fit.to_frame()

print('N =', N)
print('k =', k)

with open('Results.txt', "w") as f:
    f.write(az.summary(i_data).__str__())
    f.write('\n\n')
    f.write(d_fm['theta'].describe(percentiles =
                                   [0.025, 0.25, 0.5, 0.75, 0.975]).__str__())
print('Results.txt was saved.')

az.plot_trace(i_data)
plt.savefig('FigTrace.png')
plt.show()
print('FigTrace.png was saved.')

sb.kdeplot(d_fm['theta'])
plt.xlabel(r'$\theta$', fontsize = 16)
plt.savefig('FigTheta.png')
plt.show()
print('FigTheta.png was saved.')

